Struct libsbf::ExtSensorMeasSet
source · pub struct ExtSensorMeasSet {
pub source: u8,
pub sensor_model: u8,
pub type_: u8,
pub obs_info: u8,
pub acc: Option<ExtSensorMeasAcceleration>,
pub ang_rate: Option<ExtSensorMeasAngularRate>,
pub info: Option<ExtSensorMeasInfo>,
pub vel: Option<ExtSensorMeasVelocity>,
pub zero_vel_flag: Option<ExtSensorMeasZeroVelocityFlag>,
}Fields
source: u8sensor_model: u8type_: u8obs_info: u8acc: Option<ExtSensorMeasAcceleration>ang_rate: Option<ExtSensorMeasAngularRate>info: Option<ExtSensorMeasInfo>vel: Option<ExtSensorMeasVelocity>zero_vel_flag: Option<ExtSensorMeasZeroVelocityFlag>Trait Implementations
sourceimpl BinRead for ExtSensorMeasSet
impl BinRead for ExtSensorMeasSet
sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_> ) -> BinResult<Self>
sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moresourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moresourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moresourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moresourceimpl BinWrite for ExtSensorMeasSet
impl BinWrite for ExtSensorMeasSet
sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_> ) -> BinResult<()>
sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moresourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreAuto Trait Implementations
impl RefUnwindSafe for ExtSensorMeasSet
impl Send for ExtSensorMeasSet
impl Sync for ExtSensorMeasSet
impl Unpin for ExtSensorMeasSet
impl UnwindSafe for ExtSensorMeasSet